"""
The Trading Infrastructure Toolkit for Python.

Research, simulate, and deploy algorithmic trading strategies — all in one place.
"""

from .monitoring.console import logger


__all__ = [
    "logger",
]
